@@ -25,49 +25,62 @@
 
 "fac.combine" <- function(factors, order="standard", combine.levels=FALSE, sep=",", ...)
 {
-#
-# test arguments
-#
-	if (mode(factors) != "list" | length(factors) == 1) stop("Must supply a list")
-	nfac <- length(factors)
-	if (!all(sapply(factors, inherits, what="factor"))) 
-		stop("All elements of list must be factors or ordereds")
-	if (var(sapply(factors, length)) != 0) stop("All factors must be of the same length")
-	which.ord <- pmatch(casefold(order), c("standard", "yates"), nomatch="")
-	if (which.ord == "")	stop("order must be either standard or yates")
-# standard order
-	if (which.ord == "1") counter <- nfac:1
-# Yates order
-	else if (which.ord== "2") counter <- 1:nfac
-#
-# compute new factor
-#		
-	radix <- 1
-	new.fac <- rep(1, length(factors[[1]])) 
-	for (i in counter)
-#reassign factor so unused levels removed
-	{ f <- factor(factors[[i]])
-    nlev <- length(levels(f))
-    new.fac <- (as.numeric(f)-1) * radix + new.fac
-    if (combine.levels)
-      if (i == counter[1])
+  #
+  # test arguments
+  #
+  if (mode(factors) != "list") stop("Must supply a list")
+  if (!all(sapply(factors, inherits, what="factor"))) 
+    stop("All elements of list must be factors or ordereds")
+  new.fac <- factors[[1]]
+  nfac <- length(factors)
+  if (nfac > 1)
+  {
+    if (var(sapply(factors, length)) != 0) stop("All factors must be of the same length")
+    which.ord <- pmatch(casefold(order), c("standard", "yates"), nomatch="")
+    if (which.ord == "")	stop("order must be either standard or yates")
+    # standard order
+    if (which.ord == "1") counter <- nfac:1
+    # Yates order
+    else if (which.ord== "2") counter <- 1:nfac
+    #
+    # compute new factor
+    #		
+    radix <- 1
+    new.fac <- rep(1, length(factors[[1]])) 
+    na.lev <- FALSE
+    for (i in counter)
+      #reassign factor so unused levels removed
+    { 
+      f <- factor(factors[[i]])
+      nlev <- length(levels(f))
+      new.fac <- (as.numeric(f)-1) * radix + new.fac
+      if (combine.levels)
+      {
+        if (any(is.na(levels(f))))
+          na.lev <- TRUE
+        if (i == counter[1])
           radix.lev <- paste(levels(f))
-      else
-      { if (which.ord == 1)
+        else
+        { if (which.ord == 1)
           radix.lev <- paste(rep(levels(f), each=radix), rep(radix.lev, times=nlev), sep=sep)
         else
           radix.lev <- paste(rep(radix.lev, times=nlev), rep(levels(f), each=radix), sep=sep)
+        }
       }
-		radix <- radix * nlev
-	}
-  if (combine.levels)
-  { obslevs <- unique(new.fac)
-    obslevs <- obslevs[order(obslevs)] 
-  	new.fac <- factor(new.fac, labels=radix.lev[obslevs], ...)
-  }	
- 	else
-  	new.fac <- factor(new.fac, ...)
-	return(new.fac)
+      radix <- radix * nlev
+    }
+    if (combine.levels)
+    { 
+      obslevs <- unique(new.fac)
+      obslevs <- obslevs[order(obslevs)]
+      if (!na.lev)
+        obslevs <- obslevs[!is.na(obslevs)]
+      new.fac <- factor(new.fac, labels=radix.lev[obslevs], ...)
+    }	
+    else
+      new.fac <- factor(new.fac, ...)
+  }
+  return(new.fac)
 }
 
 "fac.divide" <- function(combined.factor, factor.names, order="standard")
@@ -124,9 +137,11 @@
 	no.lev.between <- length(levs)
 	no.lev.within <- max(table(nesting.fac))
 	nested.fac <- c(rep(1, n))
-  for(i in 1:no.lev.between)
-   nested.fac[nesting.fac == levs[i]] <- 1:reps[i]
-  	if (length(levels) == 1 && is.na(levels)) levels <- 1:no.lev.within
+	nested.fac[is.na(nesting.fac)] <-NA  #Line added
+	#Set levels if nested factor for ach levels of nested factor, avoinding missing values
+	for(i in 1:no.lev.between)
+	  nested.fac[!is.na(nesting.fac)][nesting.fac[!is.na(nesting.fac)] == levs[i]] <- 1:reps[i]
+	if (length(levels) == 1 && is.na(levels)) levels <- 1:no.lev.within
 	if (length(labels) == 1 && is.na(labels)) labels <- as.character(levels)
 	nested.fac <- factor(nested.fac, levels=levels, labels=labels, ...)
 	return(nested.fac)
